import { LitElement, TemplateResult } from 'lit';
type LabelPosition = 'left' | 'right' | 'top' | 'bottom';
declare const UUIBooleanInputElement_base: (new (...args: any[]) => import("@umbraco-ui/uui-base/lib/mixins").UUIFormControlMixinElement<FormDataEntryValue | FormData>) & (new (...args: any[]) => import("@umbraco-ui/uui-base/lib/mixins").LabelMixinInterface) & typeof LitElement;
/**
 * Base class wrapping native input type="checkbox". Extend for custom boolean input.
 * @extends LabelMixin
 * @fires UUIBooleanInputEvent#change on change
 * @abstract
 */
export declare abstract class UUIBooleanInputElement extends UUIBooleanInputElement_base {
    private _value;
    /** intentional overwrite of FormControlMixins value getter and setter method. */
    get value(): string;
    set value(newVal: string);
    /**
     * Specifies the label position of the checkbox or the toggle
     * @type {'left' | 'right' | 'top' | 'bottom'}
     * @attr label-position
     * @default right
     */
    labelPosition: LabelPosition;
    private _checked;
    /**
     * Reflects the state of the element.
     * True if checkbox or toggle is checked. Change this to switch the state programmatically.
     * @type {boolean}
     * @attr
     * @default false
     */
    get checked(): boolean;
    set checked(newVal: boolean);
    /**
     * Disables the input.
     * @type {boolean}
     * @attr
     * @default false
     */
    disabled: boolean;
    protected _input: HTMLInputElement;
    private inputRole;
    constructor(inputRole?: 'checkbox' | 'switch');
    protected getFormElement(): HTMLInputElement;
    private _onKeypress;
    hasValue(): boolean;
    formResetCallback(): void;
    protected firstUpdated(_changedProperties: Map<string | number | symbol, unknown>): void;
    /**
     * This method enables <label for="..."> to focus the input
     */
    focus(): Promise<void>;
    click(): Promise<void>;
    private _onInputChange;
    /**
     * When extending UUIBooleanInputBase class you need to implement this abstract method. It should return a template of your input.
     * @returns {TemplateResult}
     * @abstract
     * @method
     */
    protected abstract renderCheckbox(): TemplateResult;
    render(): TemplateResult<1>;
    static styles: import("lit").CSSResult[];
}
export {};
